@@ -103,6 +103,7 @@ struct _GSRWindowPrivate {
 };
 
 static GSRWindowPipeline * make_record_pipeline    (GSRWindow         *window);
+static GSRWindowPipeline * make_play_pipeline      (GSRWindow         *window);
 static void                gsr_window_init         (GSRWindow         *window);
 static void                gsr_window_class_init   (GSRWindowClass    *klass);
 static void                gsr_window_finalize     (GObject           *object);
@@ -475,16 +476,39 @@ do_save_file (GSRWindow *window,
 {
 	GSRWindowPrivate *priv;
         GMAudioProfile *profile;
-	char *tmp;
+	char *tmp, *command;
+	GError *error;
+	int status;
 	
+	status = 0;
+
 	priv = window->priv;
 	
         profile = gm_audio_profile_choose_get_active (priv->profile);
 
 	tmp = g_strdup_printf ("%s.%s", name,
 			       gm_audio_profile_get_extension (profile));
-	rename (priv->record_filename, tmp);
+	
+	command = g_strdup_printf ("/bin/cp %s %s", priv->record_filename, tmp);
+
+	if (!g_spawn_command_line_sync (command,  NULL, NULL, &status, &error)) {
+		gchar *error_message;
+
+		error_message = g_strdup_printf (_("Could not save the file \" %s\""), error->message);
+		show_error_dialog (GTK_WINDOW (window), error_message);
+		g_free (error_message);
+	}
+	
+	if (status) {
+		gchar *error_message;
+
+		error_message = g_strdup_printf (_("Could not save the file \" %s\""), tmp);
+		show_error_dialog (GTK_WINDOW (window), error_message);
+		g_free (error_message);
+	}
+
 	g_free (tmp);		
+	g_free (command);		
 }
 
 static void
@@ -936,6 +960,16 @@ media_play (BonoboUIComponent *uic,
 	if (priv->has_file == FALSE)
 		return;
 
+	if (priv->play) {
+		gst_element_set_state (priv->play->pipeline, GST_STATE_NULL);
+		g_object_unref (priv->play->pipeline);
+	}
+	priv->play = make_play_pipeline (window);
+
+	g_object_set (G_OBJECT (window->priv->play->src),
+		      "location", priv->filename,
+		      NULL);
+
 	if (priv->record && gst_element_get_state (priv->record->pipeline) == GST_STATE_PLAYING) {
 		gst_element_set_state (priv->record->pipeline, GST_STATE_READY);
 	}
@@ -960,9 +994,8 @@ media_stop (BonoboUIComponent *uic,
 		g_free (priv->working_file);
 		priv->working_file = g_strdup (priv->record_filename);
 
-		g_object_set (G_OBJECT (priv->play->src),
-			      "location", priv->working_file,
-			      NULL);
+		g_free (priv->filename);
+		priv->filename = g_strdup (priv->record_filename);
 
 		priv->dirty = TRUE;
 		priv->has_file = TRUE;
@@ -1630,7 +1663,7 @@ gsr_window_init (GSRWindow *window)
 	bonobo_ui_component_thaw (priv->ui_component, NULL);
 
 	/* Make the pipelines */
-	priv->play = make_play_pipeline (window);
+	priv->play = NULL;
 	priv->record = NULL; 
 
 	priv->len_secs = 0;
@@ -1707,9 +1740,6 @@ gsr_window_set_property (GObject      *object,
 		g_free (title);
 		g_free (short_name);
 				      
-		g_object_set (G_OBJECT (window->priv->play->src),
-			      "location", priv->filename,
-			      NULL);
 		
 		CMD_SET_SENSITIVE (window, "MediaPlay", window->priv->has_file ? "1" : "0");
 		CMD_SET_SENSITIVE (window, "MediaStop", "0");
