@@ -31,8 +31,9 @@
  
 /* Test specified inputs for pipelines */
 /* static const gchar audiosink_test_pipe[] = "afsrc location=\"" TEST_MEDIA_FILE "\""; FIXME*/
-static gchar audiosink_test_pipe[] = "sinesrc freq=512 ! audioconvert";
-static gchar videosink_test_pipe[] = "videotestsrc ! ffcolorspace";
+static gchar audiosink_test_pipe[] = "sinesrc freq=512";
+/* ffmpegcolorspace is the ripped colorspace element in gst-plugins */
+static gchar videosink_test_pipe[] = "videotestsrc";
 
 static gchar GSTPROPS_KEY_DEFAULT_VIDEOSINK[] = "default/videosink";
 static gchar GSTPROPS_KEY_DEFAULT_VIDEOSRC[] = "default/videosrc";
